@@ -1,7 +1,8 @@
 /* callbacks.c
 *
-* Copyright 2002 Sun Microsystems, Inc.,
-* Copyright 2002 University Of Toronto
+* Copyright 2002-2009 Sun Microsystems, Inc.,
+* Copyright 2002-2009 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -23,14 +24,14 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
 #include <gdk/gdkx.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #ifdef HAVE_XINPUT
 #include <X11/extensions/XInput.h>
 #endif
 
 #include <X11/Xatom.h>
-#include <glade/glade.h>
 #include "callbacks.h"
 #include "gok-scanner.h"
 #include "gok-input.h"
@@ -179,7 +180,7 @@ on_window1_enter_notify_event         (GtkWidget        *widget,
 		{
 			cursor = gdk_cursor_new (GDK_ARROW);
 			gok_main_set_cursor (cursor);
-			gdk_cursor_destroy (cursor);
+			gdk_cursor_unref (cursor);
 		}
 	}
 	return FALSE;
@@ -213,15 +214,12 @@ on_window1_configure_event        (GtkWidget       *widget,
 	
 }
 
-
 void
-on_entryName_changed                   (GtkEditable     *editable,
-                                        gpointer         user_data)
+on_comboAccessMethods_changed (GtkComboBox *combo, gpointer data)
 {
-	gok_page_accessmethod_method_changed ((GtkEditable*)editable);
+	gok_page_accessmethod_method_changed (combo);
 }
 
-
 gboolean
 on_dialogSettings_delete_event         (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -315,7 +313,6 @@ on_radiobuttonTypeSwitch_toggled       (GtkToggleButton *togglebutton,
 	gok_page_actions_toggle_type_switch (gtk_toggle_button_get_active (togglebutton));
 }
 
-
 void
 on_radiobuttonTypeValuator_toggled (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
@@ -323,19 +320,16 @@ on_radiobuttonTypeValuator_toggled (GtkToggleButton *togglebutton,
 	gok_page_actions_toggle_type_valuator (gtk_toggle_button_get_active (togglebutton));
 }
 
-
 void
-on_entryActionName_changed               (GtkEditable     *editable,
-                                        gpointer         user_data)
+on_comboActionNames_changed (GtkComboBox *combo, gpointer data)
 {
-	gok_page_actions_action_changed ((GtkEditable*)editable);
+	gok_page_actions_action_changed (combo);
 }
 
 void
-on_entry_input_device_changed          (GtkEditable     *editable,
-                                        gpointer         user_data)
+on_comboInputDevice_changed (GtkComboBox *combo, gpointer data)
 {
-	gok_page_actions_input_device_changed ((GtkEditable*)editable);
+	gok_page_actions_input_device_changed (combo);
 }
 
 void
@@ -726,7 +720,6 @@ on_buttonChangeFeedbackName_clicked    (GtkButton       *button,
 	gok_page_feedbacks_button_clicked_change_name();
 }
 
-
 void
 on_buttonFeedbackSoundFile_clicked     (GtkButton       *button,
                                         gpointer         user_data)
@@ -735,45 +728,37 @@ on_buttonFeedbackSoundFile_clicked     (GtkButton       *button,
 }
 
 void
-on_entryFeedback_changed               (GtkEditable     *editable,
-                                        gpointer         user_data)
+on_comboFeedback_changed (GtkComboBox *combo, gpointer data)
 {
-	gok_page_feedbacks_feedback_changed (editable);
-}
-
-
-void
-on_checkKeyFlashing_clicked            (GtkButton       *button,
-                                        gpointer         user_data)
-{
-	gok_page_feedbacks_check_keyflashing_clicked();
-}
-
-
-void
-on_spinKeyFlashing_changed             (GtkEditable     *editable,
-                                        gpointer         user_data)
-{
-	gok_page_feedbacks_spin_keyflashing_changed();
-}
-
-
-void
-on_checkSoundOn_clicked                (GtkButton       *button,
-                                        gpointer         user_data)
-{
-	gok_page_feedbacks_check_sound_clicked();
+	gok_page_feedbacks_feedback_changed (combo);
 }
 
 void
-on_entrySoundName_changed              (GtkEditable     *editable,
-                                        gpointer         user_data)
+on_checkKeyFlashing_toggled (GtkToggleButton *button, gpointer data)
 {
-	gok_page_feedbacks_entry_soundname_changed();
+	gok_page_feedbacks_check_keyflashing_toggled (button);
 }
 
 void
-on_SpeakLabelCheckButton_toggled (GtkToggleButton *button)
+on_spinKeyFlashing_changed (GtkEditable *editable, gpointer data)
+{
+	gok_page_feedbacks_spin_keyflashing_changed ();
+}
+
+void
+on_checkSoundOn_toggled (GtkToggleButton *button, gpointer data)
+{
+	gok_page_feedbacks_check_sound_toggled (button);
+}
+
+void
+on_comboSoundName_changed (GtkComboBox *combo, gpointer data)
+{
+	gok_page_feedbacks_soundname_changed (combo);
+}
+
+void
+on_SpeakLabelCheckButton_toggled (GtkToggleButton *button, gpointer data)
 {
 	gok_page_feedbacks_check_speech_toggled (button);
 }
@@ -876,19 +861,19 @@ void
 on_dock_checkbutton_toggled (GtkToggleButton *button, 
 			     gpointer user_data)
 {
-	GtkWidget *dockbottom, *docktop;
+	GtkWidget *docktop;
 	GokDockType dock_type;
-	gboolean is_dock = gtk_toggle_button_get_active (button);
-	GladeXML *xml = gok_settingsdialog_get_xml ();
-	dockbottom = glade_xml_get_widget (xml, "DockBottomRadiobutton");
-	docktop = glade_xml_get_widget (xml, "DockTopRadiobutton");
+	gboolean is_dock;
+
+	is_dock = gtk_toggle_button_get_active (button);
+	docktop = WID ("DockTopRadiobutton");
 
 	gtk_widget_set_sensitive (docktop, is_dock);
-	gtk_widget_set_sensitive (dockbottom, is_dock);
+	gtk_widget_set_sensitive (WID ("DockBottomRadiobutton"), is_dock);
 
 	if (is_dock)
 	{
-		if (docktop &&  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (docktop)))
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (docktop)))
 		{
 			dock_type = GOK_DOCK_TOP;
 		}
@@ -934,14 +919,6 @@ on_dock_bottom_radiobutton_toggled (GtkToggleButton *button,
 		gok_data_set_dock_type (GOK_DOCK_BOTTOM);
 }
 
-void
-on_aux_keyboard_dir_entry_changed (GtkEntry *entry,
-				   gpointer user_data)
-{
-	gok_data_set_aux_keyboard_directory (gtk_entry_get_text (entry));
-}
-
-
 void
 on_xkb_compose_keyboard_radiobutton_toggled (GtkToggleButton *button, 
 					     gpointer user_data)
@@ -974,14 +951,6 @@ on_file_compose_keyboard_radiobutton_toggled (GtkToggleButton *button,
 		gok_data_set_compose_keyboard_type (GOK_COMPOSE_CUSTOM);
 }
 
-void
-on_compose_keyboard_file_entry_changed (GtkEditable *editable, 
-					gpointer user_data)
-{
-	gok_data_set_custom_compose_filename (
-		gtk_editable_get_chars (editable, 0, -1));
-}
-
 void
 on_core_pointer_button_toggled         (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
@@ -990,7 +959,6 @@ on_core_pointer_button_toggled         (GtkToggleButton *togglebutton,
 		gtk_toggle_button_get_active (togglebutton));
 }
 
-
 void
 on_xinput_device_button_toggled        (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
