@@ -100,8 +100,6 @@ char* gok_data_get_name_accessmethod (void);
 void	gok_data_set_name_accessmethod (const gchar* Name);
 gboolean gok_data_get_wordcomplete (void);
 void gok_data_set_wordcomplete (gboolean bTrueFalse);
-gboolean gok_data_get_commandprediction();
-void gok_data_set_commandprediction(gboolean bTrueFalse);
 gint gok_data_get_num_predictions (void);
 void gok_data_set_num_predictions(gint Number);
 void gok_data_backup_settings (void);
