@@ -23,10 +23,10 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
-
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
+#include <glib.h>
+#include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
 #include "gok-gconf-keys.h"
 #include "gok-log.h"
