@@ -2,6 +2,7 @@
 *
 * Copyright 2002-2009 Sun Microsystems, Inc.,
 * Copyright 2002-2009 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -24,8 +25,6 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
-#include <glib.h>
 #include <glib/gi18n.h>
 #include "gok-page-actions.h"
 #include "gok-action.h"
@@ -49,77 +48,65 @@ static gboolean m_bChanged;
 
 /**
 * gok_page_actions_initialize
-* @pWindowSettings: Pointer to the settings dialog window.
 *
 * Initializes this page of the gok settings dialog. This must be called
 * prior to any calls on this page.
 *
 * returns: TRUE if the page was properly initialized, FALSE if not.
 **/
-gboolean gok_page_actions_initialize (GladeXML* xml)
+gboolean gok_page_actions_initialize (void)
 {
-	GtkWidget* pComboBox, *range;
+	GtkComboBox *pComboBox;
+	GtkWidget *range;
 	GokAction* pAction;
-	GList* items = NULL;
-	GSList* pDevice = NULL;
-	GSList* slist;
-	gboolean bReturnCode = TRUE; /* unused? */
-	
-	g_assert (xml != NULL);
+	GSList* pDevice;
+
 	m_pActionCurrent = gok_action_get_first_action ();
 	m_bIgnoreChangeName = FALSE;
 	m_bChanged = TRUE;
 
 	/* add all the actions to the combo box */
-	pComboBox = glade_xml_get_widget (xml, "comboActionNames");
-	g_assert (pComboBox != NULL);
-	
+	gok_settingsdialog_combobox_init (GTK_COMBO_BOX (OID ("comboActionNames")), TRUE);
 	gok_page_actions_fill_combo_action_names();
-	
 	gok_page_actions_update_controls (gok_action_get_first_action ());
 
 	/* initialize the XInput device combobox */
-	pComboBox = glade_xml_get_widget (xml, "comboInputDevice");
+	pComboBox = GTK_COMBO_BOX (OID ("comboInputDevice"));
 	g_assert (pComboBox != NULL);
+	gok_settingsdialog_combobox_init (pComboBox, FALSE);
 	
 	pDevice = gok_input_get_device_list ();
-	if (pDevice)
+	while (pDevice)
 	{
-		items = NULL;
-		slist = pDevice;
-		while ((slist != NULL) && (slist->data != NULL))
-		{
-			GokInput *input;
-			input = (GokInput *) slist->data;
-			/* small hack so that the gconf stored extension device will
-			   be at the top of the list, and therefore not overridden 
-			   TODO: store this as part of an action */
-			if (strcmp(input->name, gok_input_get_extension_device_name()) == 0) {
-				items = g_list_prepend (items, input->name );
-			}
-			else {
-				items = g_list_append (items, input->name);
-			}
-			/* TODO: persist this list so we can query it later */
-			slist = slist->next;
+		GokInput *input = pDevice->data;
+
+		/* small hack so that the gconf stored extension device will
+		   be at the top of the list, and therefore not overridden
+		   TODO: store this as part of an action */
+		if (strcmp(input->name, gok_input_get_extension_device_name()) == 0) {
+			gtk_combo_box_prepend_text (pComboBox, input->name );
 		}
-		if (!gok_input_get_extension_device_name() ||
-		    !strlen(gok_input_get_extension_device_name())) {
-		         items = g_list_prepend (items, "");
+		else {
+			gtk_combo_box_append_text (pComboBox, input->name);
 		}
-		gtk_combo_set_popdown_strings (GTK_COMBO (pComboBox), items);
-		g_list_free (items);
+		/* TODO: persist this list so we can query it later */
+		pDevice = pDevice->next;
 	}
+	if (!gok_input_get_extension_device_name() ||
+	    !strlen(gok_input_get_extension_device_name())) {
+		gtk_combo_box_prepend_text (pComboBox, "");
+	}
+
+	/* select first entry */
+	gok_settingsdialog_combobox_set_active (pComboBox, "");
 
 	gok_page_actions_enable_radios_type (FALSE);
 
 	/* init the (now-global) valuator sensitivity slider */
-	range = glade_xml_get_widget (xml, "ValuatorSensitivityScale");
-	g_assert (range != NULL);
-	gtk_range_set_value (GTK_RANGE (range), 
+	gtk_range_set_value (GTK_RANGE (OID ("ValuatorSensitivityScale")),
 			     gok_data_get_valuator_sensitivity ());
 
-	return bReturnCode;
+	return TRUE;
 }
 
 /**
@@ -249,79 +236,44 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 {
 	GtkToggleButton* pRadioButton;
 	GtkSpinButton* pSpinButton;
-	GtkNotebook *pNotebook;
 
 	g_assert (m_pActionCurrent != NULL);
 
-	pNotebook = (GtkNotebook*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
-			"action_type_notebook");
-	g_assert (pNotebook != NULL);
-	gtk_notebook_set_current_page (pNotebook, (Pressed) ? 0 : 1);
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (OID ("action_type_notebook")),
+				       Pressed ? 0 : 1);
+	if (Pressed)
+	{
+		/* update the action from the controls */
+		m_pActionCurrent->Type = ACTION_TYPE_SWITCH;
+		/* TODO: fix to allow MOUSEBUTTON also */
 
-	if (Pressed == TRUE)
-	{
-	/* update the action from the controls */
-	m_pActionCurrent->Type = ACTION_TYPE_SWITCH;
-	/* TODO: fix to allow MOUSEBUTTON also */
-
-	pRadioButton = (GtkToggleButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
-			"radiobuttonSwitch1");
-	g_assert (pRadioButton != NULL);
-	if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
-	{
-		m_pActionCurrent->Number = 1;
-	}
-	else
-	{
-		pRadioButton = (GtkToggleButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
-				"radiobuttonSwitch2");
-		g_assert (pRadioButton != NULL);
-		if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch1"))))
+		{
+			m_pActionCurrent->Number = 1;
+		}
+		else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch2"))))
 		{
 			m_pActionCurrent->Number = 2;
 		}
+		else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch3"))))
+		{
+			m_pActionCurrent->Number = 3;
+		}
+		else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch4"))))
+		{
+			m_pActionCurrent->Number = 4;
+		}
 		else
 		{
-			pRadioButton = (GtkToggleButton*) glade_xml_get_widget (
-					gok_settingsdialog_get_xml(), "radiobuttonSwitch3");
-			g_assert (pRadioButton != NULL);
-			if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
-			{
-				m_pActionCurrent->Number = 3;
-			}
-			else
-			{
-				pRadioButton = (GtkToggleButton*) glade_xml_get_widget (
-						gok_settingsdialog_get_xml(), "radiobuttonSwitch4");
-				g_assert (pRadioButton != NULL);
-				if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
-				{
-					m_pActionCurrent->Number = 4;
-				}
-				else
-				{
-					m_pActionCurrent->Number = 5;
-				}
-			}
+			m_pActionCurrent->Number = 5;
 		}
-	}
 
-	pRadioButton = (GtkToggleButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
-			"radiobuttonPress");
-	g_assert (pRadioButton != NULL);
-	if (gtk_toggle_button_get_active (pRadioButton) == TRUE)
-	{
-		m_pActionCurrent->State = ACTION_STATE_PRESS;
-	}
-	else
-	{
-		m_pActionCurrent->State = ACTION_STATE_RELEASE;
-	}
+		m_pActionCurrent->State =
+			gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonPress")))
+			? ACTION_STATE_PRESS : ACTION_STATE_RELEASE;
 
-	pSpinButton = (GtkSpinButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
-			"spinDelay");
-	g_assert (pSpinButton != NULL);
-	m_pActionCurrent->Rate = gtk_spin_button_get_value_as_int (pSpinButton);
+		m_pActionCurrent->Rate =
+			gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (OID ("spinDelay")));
 	}
 	
 	gok_page_actions_enable_switch_controls (Pressed);
@@ -336,18 +288,15 @@ void gok_page_actions_toggle_type_switch (gboolean Pressed)
 **/
 void gok_page_actions_toggle_type_valuator (gboolean Pressed)
 {
-	GtkSpinButton* pSpinButton;
-
 	g_assert (m_pActionCurrent != NULL);
 
 	if (Pressed == TRUE)
 	{
 		/* TODO: consider disabling some controls here */
 	}	
-	pSpinButton = (GtkSpinButton*) glade_xml_get_widget (gok_settingsdialog_get_xml(), 
-			"pointer_delay_spinbutton");
-	g_assert (pSpinButton != NULL);
-	m_pActionCurrent->Rate = gtk_spin_button_get_value_as_int (pSpinButton);
+
+	m_pActionCurrent->Rate =
+		gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (OID ("pointer_delay_spinbutton")));
 
 	gok_page_actions_enable_valuator_controls (Pressed);
 }
@@ -536,26 +485,22 @@ void gok_page_actions_button_clicked_new ()
 void gok_page_actions_button_clicked_delete ()
 {
 	GtkWidget* pDialog;
-	GtkWidget* pComboEntry;
+	GtkComboBox *combo;
 	const gchar* pNameAction;
-	gchar buffer[200];
+	gchar *buffer;
 	gint result;
 	GokAction* pAction;
 	GokAction* pActionDisplayed;
 	
-	pComboEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryActionName");
-	g_assert (pComboEntry != NULL);
-	pNameAction = gtk_entry_get_text (GTK_ENTRY(pComboEntry));
+	pNameAction = gtk_combo_box_get_active_text (GTK_COMBO_BOX (OID ("comboActionNames")));
+	buffer = g_strdup_printf (_("Do you wish to delete this action (%s)?"), pNameAction);
 
-	sprintf (buffer, _("Do you wish to delete this action (%s)?"), pNameAction);
-
-	/*** TODO: code duplication ***/
 	pDialog = gtk_message_dialog_new ((GtkWindow*)gok_settingsdialog_get_window(),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_QUESTION,
 			GTK_BUTTONS_YES_NO,
 			"%s", buffer);
-	
+	g_free (buffer);
 	gtk_window_set_title (GTK_WINDOW (pDialog), _("GOK Delete Action"));
 	result = gtk_dialog_run (GTK_DIALOG (pDialog));
 	gtk_widget_destroy (pDialog);
@@ -606,65 +551,45 @@ void gok_page_actions_button_clicked_delete ()
 **/
 void gok_page_actions_fill_combo_action_names ()
 {
-	GtkWidget* pComboBox;
-	GtkWidget* pEntry;
+	GtkComboBox* pComboBox;
 	GokAction* pAction;
-	GList* items = NULL;
-	gchar* pActionName;
 
-	/* ignore the 'entry text changed' message generated by this routine */
+	/* ignore combo box 'changed' signals */
 	m_bIgnoreChangeName = TRUE;
 	
 	/* find the combo box */
-	pComboBox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboActionNames");
-	g_assert (pComboBox != NULL);
+	pComboBox = GTK_COMBO_BOX (OID ("comboActionNames"));
 
-	/* create a list of action display names */
+	/* clear the combo box model, we might be refilling */
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (pComboBox)));
+
+	/* fill combo box with action display names */
 	pAction = gok_action_get_first_action();
 	while (pAction != NULL)
 	{
-		items = g_list_append (items, pAction->pDisplayName);
+		gtk_combo_box_prepend_text (pComboBox, pAction->pDisplayName);
 		pAction = pAction->pActionNext;
 	}
-	
-	/* are there any action names? */
-	if (items == NULL)
-	{
-		/* no, so empty the combo box */
-		items = g_list_append (items, "");
-	}
 
-	/* sort the action names */
-	items = g_list_sort (items, gok_settingsdialog_sort);
-
-	gtk_combo_set_popdown_strings (GTK_COMBO (pComboBox), items);
-	g_list_free (items);
-
-	/* display the current action name in the entry control of the combo */
+	/* display the current action name */
 	if (m_pActionCurrent != NULL)
 	{
-		pActionName = m_pActionCurrent->pDisplayName;
+		gok_settingsdialog_combobox_set_active (pComboBox,
+							m_pActionCurrent->pDisplayName);
 	}
-	else
-	{
-		pActionName = "";
-	}
-	pEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryActionName");
-	g_assert (pEntry != NULL);
-	gtk_entry_set_text (GTK_ENTRY(pEntry), pActionName);
-	
+
 	m_bIgnoreChangeName = FALSE;
 }
 
 /**
 * gok_page_actions_action_changed
-* @pEditControl: Pointer to the edit control that contains the names of
+* @combo: Pointer to the combo box that contains the names of
 * the actions.
 *
 * The user has selected a new action from the combo box so update the
 * page's controls with the new action data.
 **/
-void gok_page_actions_action_changed (GtkEditable* pEditControl)
+void gok_page_actions_action_changed (GtkComboBox *combo)
 {
 	GokAction* pAction;
 	gchar* pStrComboActionName;
@@ -678,7 +603,7 @@ void gok_page_actions_action_changed (GtkEditable* pEditControl)
 	}
 
 	/* get the name of the action from the combo box */
-	pStrComboActionName = gtk_editable_get_chars (pEditControl, 0, -1);
+	pStrComboActionName = gtk_combo_box_get_active_text (combo);
 	if (strlen (pStrComboActionName) == 0)
 	{
 		g_free (pStrComboActionName);
@@ -698,7 +623,6 @@ void gok_page_actions_action_changed (GtkEditable* pEditControl)
 	m_pActionCurrent = pAction;
 	
 	/* update the controls to reflect this action */
-
 	gok_page_actions_update_controls (pAction);
 }
 
@@ -710,24 +634,23 @@ void gok_page_actions_action_changed (GtkEditable* pEditControl)
 * The user has selected a new input device from the combo box so update the
 * page's controls with the new input device data.
 **/
-void gok_page_actions_input_device_changed (GtkEditable* pEditControl)
+void gok_page_actions_input_device_changed (GtkComboBox *combo)
 {
 	gchar* pStrComboInputDeviceName;
 	GokInput *pInput;
 
 	/* get the name of the input device from the combo box */
-	pStrComboInputDeviceName = gtk_editable_get_chars (pEditControl, 0, -1);
+	pStrComboInputDeviceName = gtk_combo_box_get_active_text (combo);
 	if (pStrComboInputDeviceName && strlen (pStrComboInputDeviceName) == 0) {
 		g_free (pStrComboInputDeviceName);
 	}
 	else if (pStrComboInputDeviceName)
 	{
 		/* find the device in our list of input devices */
-	        
 		pInput = gok_input_find_by_name (pStrComboInputDeviceName, TRUE);
 		if (!pInput) {
 			gok_log_x ("Input Device name (%s) from combo not found in device list!", pStrComboInputDeviceName);
-			gtk_editable_delete_text (pEditControl, 0, -1);
+			gok_settingsdialog_combobox_set_active (combo, "");
 		}
 		else {
 			gok_page_actions_set_changed ( TRUE );
@@ -746,11 +669,6 @@ void gok_page_actions_input_device_changed (GtkEditable* pEditControl)
 **/
 void gok_page_actions_update_controls (GokAction* pAction)
 {
-	GtkWidget* pRadioButton;
-	GtkWidget* pSpinControl;
-	GtkWidget* pCheckbox;
-	GtkWidget* pButton;
-	
 	/* if no action then disable all the controls */
 	if (pAction == NULL)
 	{
@@ -760,70 +678,33 @@ void gok_page_actions_update_controls (GokAction* pAction)
 		return;
 	}
 	
-	/* is this a permanent action? */
-	if (pAction->bPermanent == TRUE)
-	{
-		/* don't allow user to edit the action name */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeName");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-			
-		gok_page_actions_enable_radios_type (FALSE);
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteAction");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-	}
-	else
-	{
-		/* not permanent, enable controls for changing action type */
-		gok_page_actions_enable_radios_type (TRUE);
-						
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteAction");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, TRUE);
-						
-		/* allow user to edit the action name */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeName");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, TRUE);
-	}
+	/* enable radio controls if this action isn't permanent */
+	gok_page_actions_enable_radios_type (!pAction->bPermanent);
+	/* enable delete & rename buttons if the action isn't permanent */
+	gtk_widget_set_sensitive (WID ("buttonChangeName"), !pAction->bPermanent);
+	gtk_widget_set_sensitive (WID ("buttonDeleteAction"), !pAction->bPermanent);
 
 	/* update the values for all controls */	
 	switch (pAction->Number)
 	{
 		case 1:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch1");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch1")), TRUE);
 			break;
 	
 		case 2:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch2");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch2")), TRUE);
 			break;
 	
 		case 3:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch3");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch3")), TRUE);
 			break;
 	
 		case 4:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch4");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch4")), TRUE);
 			break;
 	
 		case 5:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonSwitch5");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonSwitch5")), TRUE);
 			break;
 	
 		default:
@@ -833,33 +714,21 @@ void gok_page_actions_update_controls (GokAction* pAction)
 	switch (pAction->State)
 	{
 		case ACTION_STATE_PRESS:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonPress");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonPress")), TRUE);
 			break;
 			
 		case ACTION_STATE_RELEASE:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonRelease");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonRelease")), TRUE);
 			break;
 			
 		default:
 			gok_log_x ("default hit!\n");
 			break;
 	}
-	
-	pSpinControl = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinDelay");
-	g_assert (pSpinControl != NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpinControl), pAction->Rate);
 
-	pSpinControl = glade_xml_get_widget (gok_settingsdialog_get_xml(), "pointer_delay_spinbutton");
-	g_assert (pSpinControl != NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pSpinControl), pAction->Rate);
-	
-	pCheckbox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyAverage");
-	g_assert (pSpinControl != NULL);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pCheckbox), pAction->bKeyAveraging);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("spinDelay")), pAction->Rate);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("pointer_delay_spinbutton")), pAction->Rate);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("checkKeyAverage")), pAction->bKeyAveraging);
 
 	/* enable/disable the appropriate controls */
 	switch (pAction->Type)
@@ -868,32 +737,20 @@ void gok_page_actions_update_controls (GokAction* pAction)
 		case ACTION_TYPE_MOUSEBUTTON:
 		case ACTION_TYPE_KEY:
 			/* enable/disable the controls for switch actions */
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeSwitch");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonTypeSwitch")), TRUE);
 			gok_page_actions_enable_switch_controls (TRUE);
 			gok_page_actions_enable_valuator_controls (FALSE);
 			break;
 							
 		case ACTION_TYPE_DWELL:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeValuator");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-							
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "activate_on_dwell_button");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonTypeValuator")), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("activate_on_dwell_button")), TRUE);
 			gok_page_actions_enable_switch_controls (FALSE);
 			gok_page_actions_enable_valuator_controls (TRUE);
 			break;
 		case ACTION_TYPE_MOUSEPOINTER:
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeValuator");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-			pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "activate_on_enter_button");
-			g_assert (pRadioButton != NULL);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
-							
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("radiobuttonTypeValuator")), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("activate_on_enter_button")), TRUE);
 			gok_page_actions_enable_switch_controls (FALSE);
 			gok_page_actions_enable_valuator_controls (TRUE);
 			break;
@@ -902,16 +759,15 @@ void gok_page_actions_update_controls (GokAction* pAction)
 			gok_log_x ("default hit!\n");
 			break;
 	}
-	pRadioButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "xinput_device_button");
-	g_assert (pRadioButton != NULL);
+
 	switch (pAction->Type)
 	{
 	case ACTION_TYPE_SWITCH:
 	case ACTION_TYPE_KEY:
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("xinput_device_button")), TRUE);
 		break;
 	case ACTION_TYPE_MOUSEBUTTON:
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pRadioButton), FALSE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (OID ("xinput_device_button")), FALSE);
 		break;
 	default:
 		break;
@@ -927,19 +783,11 @@ void gok_page_actions_update_controls (GokAction* pAction)
 **/
 void gok_page_actions_enable_switch_controls (gboolean bTrueFalse)
 {
-	GtkWidget* pFrame, *pNotebook;
-
-	pFrame = glade_xml_get_widget (gok_settingsdialog_get_xml(), "frameSwitch");
-	g_assert (pFrame != NULL);
-	
-	gtk_widget_set_sensitive (pFrame, bTrueFalse);
+	gtk_widget_set_sensitive (WID ("frameSwitch"), bTrueFalse);
 	
 	if (bTrueFalse) 
 	{
-		pNotebook = glade_xml_get_widget (gok_settingsdialog_get_xml(), "action_type_notebook");
-		g_assert (pNotebook != NULL);
-		
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (pNotebook), 0);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (OID ("action_type_notebook")), 0);
 	}
 }
 
@@ -951,19 +799,11 @@ void gok_page_actions_enable_switch_controls (gboolean bTrueFalse)
 **/
 void gok_page_actions_enable_valuator_controls (gboolean bTrueFalse)
 {
-	GtkWidget* pFrame, *pNotebook;
-
-	pFrame = glade_xml_get_widget (gok_settingsdialog_get_xml(), "frameSwitch");
-	g_assert (pFrame != NULL);
-	
-	gtk_widget_set_sensitive (pFrame, bTrueFalse);
+	gtk_widget_set_sensitive (WID ("frameSwitch"), bTrueFalse);
 
 	if (bTrueFalse)
 	{
-		pNotebook = glade_xml_get_widget (gok_settingsdialog_get_xml(), "action_type_notebook");
-		g_assert (pNotebook != NULL);
-		
-		gtk_notebook_set_current_page (GTK_NOTEBOOK (pNotebook), 1);
+		gtk_notebook_set_current_page (GTK_NOTEBOOK (WID ("action_type_notebook")), 1);
 	}
 }
 
@@ -975,20 +815,9 @@ void gok_page_actions_enable_valuator_controls (gboolean bTrueFalse)
 **/
 void gok_page_actions_enable_radios_type (gboolean bTrueFalse)
 {
-	GtkWidget* pWidget;
-
-	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "labelActionName");
-	g_assert (pWidget != NULL);
-	gtk_widget_set_sensitive (pWidget, bTrueFalse);
-	
-	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeSwitch");
-	g_assert (pWidget != NULL);
-	gtk_widget_set_sensitive (pWidget, bTrueFalse);
-	
-	pWidget = glade_xml_get_widget (gok_settingsdialog_get_xml(), "radiobuttonTypeValuator");
-	g_assert (pWidget != NULL);
-	gtk_widget_set_sensitive (pWidget, bTrueFalse);
-	
+	gtk_widget_set_sensitive (WID ("labelActionType"), bTrueFalse);
+	gtk_widget_set_sensitive (WID ("radiobuttonTypeSwitch"), bTrueFalse);
+	gtk_widget_set_sensitive (WID ("radiobuttonTypeValuator"), bTrueFalse);
 }
 
 /**
