@@ -2,6 +2,7 @@
 *
 * Copyright 2002-2009 Sun Microsystems, Inc.,
 * Copyright 2002-2009 University Of Toronto
+* Copyright 2009 Gerd Kohlberger <gerdko gmail com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -24,8 +25,7 @@
 #endif
 
 #include <gtk/gtk.h>
-#include <glib.h>
-#include <glib/gi18n.h>
+
 #include "gok-page-feedbacks.h"
 #include "gok-feedback.h"
 #include "gok-log.h"
@@ -41,7 +41,7 @@ static gboolean m_bIgnoreChangeName;
 /* this is not changed if an existing feedback is just modified */
 static gboolean m_bChanged;
 
-/* this should be set TRUE when we change the name in the sound name entry field */
+/* this should be set TRUE when we change the name in the sound name combo box */
 static gboolean m_bIgnoreSoundNameChange;
 
 /**
@@ -53,48 +53,40 @@ static gboolean m_bIgnoreSoundNameChange;
 *
 * returns: TRUE if the page was properly initialized, FALSE if not.
 **/
-gboolean gok_page_feedbacks_initialize (GladeXML* xml)
+gboolean gok_page_feedbacks_initialize (void)
 {
-	GtkWidget* pComboBox;
+	GtkComboBox* pComboBox;
 	GokFeedback* pFeedback;
-	GList* items = NULL;
-	
-	g_assert (xml != NULL);
+
 	m_pFeedbackCurrent = NULL;
-	m_bIgnoreChangeName = FALSE;
 	m_bChanged = TRUE;
-	m_bIgnoreSoundNameChange = FALSE;
+
+	pComboBox = GTK_COMBO_BOX (OID ("comboSoundName"));
+	gok_settingsdialog_combobox_init (pComboBox, TRUE);
 
 	/* add all sounds to the 'sounds' combo box */
-	gok_feedbacks_update_sound_combo();
-	
-	/* add all the feedbacks to the combo box */
-	pComboBox = glade_xml_get_widget (xml , "comboFeedback");
-	g_assert (pComboBox != NULL);
+	gok_feedbacks_update_sound_combo ();
 
+	pComboBox = GTK_COMBO_BOX (OID ("comboFeedback"));
+	gok_settingsdialog_combobox_init (pComboBox, TRUE);
+
+	m_bIgnoreChangeName = TRUE;
+
+	/* add all the feedbacks to the combo box */
 	pFeedback = gok_feedback_get_first_feedback();
 	while (pFeedback != NULL)
 	{
-		items = g_list_append (items, pFeedback->pDisplayName);
+		gtk_combo_box_prepend_text (pComboBox, pFeedback->pDisplayName);
 		pFeedback = pFeedback->pFeedbackNext;
 	}
 
-	if (items != NULL)
-	{
-		/* sort the names */
-		items = g_list_sort (items, gok_settingsdialog_sort);
+	m_pFeedbackCurrent = gok_feedback_find_feedback ("None", TRUE);
+	gok_settingsdialog_combobox_set_active (pComboBox, "None");
+
+	m_bIgnoreChangeName = FALSE;
+
+	gok_page_feedbacks_update_controls (m_pFeedbackCurrent);
 
-		m_bIgnoreChangeName = TRUE;
-		gtk_combo_set_popdown_strings (GTK_COMBO (pComboBox), items);
-		m_bIgnoreChangeName = FALSE;
-		g_list_free (items);
-	}
-	
-	if (m_pFeedbackCurrent == NULL)
-	{
-		gok_page_feedbacks_update_controls (NULL);
-	}
-	
 	return TRUE;
 }
 
@@ -214,13 +206,13 @@ void gok_page_feedbacks_backup ()
 
 /**
 * gok_page_feedbacks_feedback_changed
-* @pEditControl: Pointer to the edit control that contains the names of
+* @combo: Pointer to the combo box that contains the names of
 * the feedbacks.
 *
-* The feedback name in the entry control has changed. Update the
+* The feedback name in the combo box has changed. Update the
 * page's controls with the new feedback data.
 **/
-void gok_page_feedbacks_feedback_changed (GtkEditable* pEditControl)
+void gok_page_feedbacks_feedback_changed (GtkComboBox *combo)
 {
 	GokFeedback* pFeedback;
 	gchar* pStrComboFeedbackName;
@@ -233,7 +225,7 @@ void gok_page_feedbacks_feedback_changed (GtkEditable* pEditControl)
 		return;
 	}
 	/* get the name of the feedback from the combo box */
-	pStrComboFeedbackName = gtk_editable_get_chars (pEditControl, 0, -1);
+	pStrComboFeedbackName = gtk_combo_box_get_active_text (combo);
 
 	if (strlen (pStrComboFeedbackName) == 0)
 	{
@@ -265,133 +257,67 @@ void gok_page_feedbacks_feedback_changed (GtkEditable* pEditControl)
 **/
 void gok_page_feedbacks_update_controls (GokFeedback* pFeedback)
 {
-	GtkWidget* pButton;
-	
-	/* if no feedback then disable all controls */
+	GtkWidget *widget;
+	gboolean enable_all;
+
+	/*
+	 * disable all controls if there's no feedback selected,
+	 * or the current feedback is "None"
+	 */
+	enable_all = (pFeedback != NULL && !g_str_equal (pFeedback->pDisplayName, "None"));
+	gtk_widget_set_sensitive (WID ("boxKeyFlashing"), enable_all);
+	gtk_widget_set_sensitive (WID ("boxSound"), enable_all);
+	gtk_widget_set_sensitive (WID ("boxSpeech"), enable_all);
+	gtk_widget_set_sensitive (WID ("buttonChangeFeedbackName"), enable_all);
+	gtk_widget_set_sensitive (WID ("buttonDeleteFeedback"), enable_all);
+
 	if (pFeedback == NULL)
 	{
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeFeedbackName");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-			
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteFeedback");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyFlashing");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinKeyFlashing");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkSoundOn");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboSoundName");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonFeedbackSoundFile");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "SpeakLabelCheckButton");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-
 		return;
 	}
 
-	/* is this a permanent feedback? */
-	if (pFeedback->bPermanent == TRUE)
-	{
-		/* don't allow user to edit the feedback name */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeFeedbackName");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-		
-		/* don't allow user to delete the feedback */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteFeedback");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-		
-		/* don't allow user to change the flashing on/off */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyFlashing");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bFlashOn);
+	/*
+	 * disable some controls if this is a permanent feedback
+	 */
 
-		/* don't allow user to change the sound on/off */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkSoundOn");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, FALSE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bSoundOn);
-	}
-	else
-	{
-		/* not permanent */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonDeleteFeedback");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, TRUE);
-						
-		/* allow user to edit the feedback name */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonChangeFeedbackName");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, TRUE);
+	/* edit & delete button */
+	gtk_widget_set_sensitive (WID ("buttonChangeFeedbackName"), !pFeedback->bPermanent);
+	gtk_widget_set_sensitive (WID ("buttonDeleteFeedback"), !pFeedback->bPermanent);
 
-		/* allow user to change the flashing on/off */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyFlashing");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, TRUE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bFlashOn);
+	/* change key flashing */
+	widget = WID ("checkKeyFlashing");
+	gtk_widget_set_sensitive (widget, !pFeedback->bPermanent);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), pFeedback->bFlashOn);
 
-		/* allow user to change the sound on/off */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkSoundOn");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, TRUE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bSoundOn);
+	/* change sound */
+	widget = WID ("checkSoundOn");
+	gtk_widget_set_sensitive (widget, !pFeedback->bPermanent);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), pFeedback->bSoundOn);
 
-		/* allow user to turn the speech on/off */
-		pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "SpeakLabelCheckButton");
-		g_assert (pButton != NULL);
-		gtk_widget_set_sensitive (pButton, TRUE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(pButton), pFeedback->bSpeechOn);
-	}
-	
-	pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinKeyFlashing");
-	g_assert (pButton != NULL);
-	gtk_widget_set_sensitive (pButton, TRUE);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(pButton), pFeedback->NumberFlashes);
+	/* change speech */
+	widget = WID ("SpeakLabelCheckButton");
+	gtk_widget_set_sensitive (widget, !pFeedback->bPermanent);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), pFeedback->bSpeechOn);
 
-	pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboSoundName");
-	g_assert (pButton != NULL);
-	gtk_widget_set_sensitive (pButton, TRUE);
+	/*
+	 * update details
+	 */
 
-	pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entrySoundName");
-	g_assert (pButton != NULL);
-	gtk_widget_set_sensitive (pButton, TRUE);
+	/* key flashing rate */
+	gtk_widget_set_sensitive (WID ("boxKeyFlashing"), pFeedback->bFlashOn);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (OID ("spinKeyFlashing")),
+				   pFeedback->NumberFlashes);
+
+	/* sound file */
+	gtk_widget_set_sensitive (WID ("boxSoundFile"), pFeedback->bSoundOn);
 	m_bIgnoreSoundNameChange = TRUE;
-	
-	if (pFeedback->pNameSound != NULL)
-	{
-		gtk_entry_set_text (GTK_ENTRY(pButton), pFeedback->pNameSound);
-	}
-	else
-	{
-		gtk_entry_set_text (GTK_ENTRY(pButton), "");
-	}
+	gok_settingsdialog_combobox_set_active (GTK_COMBO_BOX (OID ("comboSoundName")),
+						pFeedback->pNameSound ? pFeedback->pNameSound : "none");
 	m_bIgnoreSoundNameChange = FALSE;
-
-	pButton = glade_xml_get_widget (gok_settingsdialog_get_xml(), "buttonFeedbackSoundFile");
-	g_assert (pButton != NULL);
-	gtk_widget_set_sensitive (pButton, TRUE);
 }
 
 /**
-* gok_page_feedbacks_button_clicked_change_name
+ * gok_page_feedbacks_button_clicked_change_name
 * 
 * The button "change name" has been clicked so allow the user to change the
 * name of the feedback.
@@ -541,7 +467,7 @@ void gok_page_feedbacks_button_clicked_new()
 		pFeedbackNew->bSoundOn = m_pFeedbackCurrent->bSoundOn;
 		if (m_pFeedbackCurrent->pNameSound != NULL)
 		{
-                    pFeedbackNew->pNameSound = g_strdup (m_pFeedbackCurrent->pNameSound);
+			pFeedbackNew->pNameSound = g_strdup (m_pFeedbackCurrent->pNameSound);
 		}
 	}
 	
@@ -564,58 +490,37 @@ void gok_page_feedbacks_button_clicked_new()
 * gok_page_feedbacks_fill_combo_feedback_names
 *
 * Fills the combo box that displays the feedback names.
-* This also displays the name of the current feedback in the entry control.
+* This also displays the name of the current feedback in the combo box.
 **/
 void gok_page_feedbacks_fill_combo_feedback_names ()
 {
-	GtkWidget* pComboBox;
-	GtkWidget* pEntry;
+	GtkComboBox* pComboBox;
 	GokFeedback* pFeedback;
-	GList* items = NULL;
-	gchar* pFeedbackName;
 
-	/* ignore the 'entry text changed' message generated by this routine */
+	/* ignore the combo box 'changed' signals */
 	m_bIgnoreChangeName = TRUE;
 	
 	/* find the combo box */
-	pComboBox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboFeedback");
-	g_assert (pComboBox != NULL);
+	pComboBox = GTK_COMBO_BOX (OID ("comboFeedback"));
+
+	/* clear the combo box model. we might be refilling */
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (pComboBox)));
 
 	/* create a list of feedback display names */
 	pFeedback = gok_feedback_get_first_feedback();
 	while (pFeedback != NULL)
 	{
-		items = g_list_append (items, pFeedback->pDisplayName);
+		gtk_combo_box_prepend_text (pComboBox, pFeedback->pDisplayName);
 		pFeedback = pFeedback->pFeedbackNext;
 	}
-	
-	/* are there any feedback names? */
-	if (items == NULL)
-	{
-		/* no, so empty the combo box */
-		items = g_list_append (items, "");
-	}
-	/* sort the names */
-	items = g_list_sort (items, gok_settingsdialog_sort);
 
-	gtk_combo_set_popdown_strings (GTK_COMBO (pComboBox), items);
-	g_list_free (items);
+	/* display the current feedback name in the combo box */
+	gok_settingsdialog_combobox_set_active (pComboBox,
+						m_pFeedbackCurrent ?
+						m_pFeedbackCurrent->pDisplayName : "");
 
-	/* display the current feedback name in the entry control of the combo */
-	if (m_pFeedbackCurrent != NULL)
-	{
-		pFeedbackName = m_pFeedbackCurrent->pDisplayName;
-	}
-	else
-	{
-		pFeedbackName = "";
-	}
-	pEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryFeedback");
-	g_assert (pEntry != NULL);
-	gtk_entry_set_text (GTK_ENTRY(pEntry), pFeedbackName);
-	
 	m_bIgnoreChangeName = FALSE;
-}	
+}
 
 /**
 * gok_page_feedbacks_button_clicked_delete
@@ -625,16 +530,14 @@ void gok_page_feedbacks_fill_combo_feedback_names ()
 void gok_page_feedbacks_button_clicked_delete ()
 {
 	GtkWidget* pDialog;
-	GtkWidget* pComboEntry;
-	const gchar* pNameFeedback;
+	gchar* pNameFeedback;
 	gchar buffer[200];
 	gint result;
 	GokFeedback* pFeedback;
 	GokFeedback* pFeedbackDisplayed;
-	
-	pComboEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entryFeedback");
-	g_assert (pComboEntry != NULL);
-	pNameFeedback = gtk_entry_get_text (GTK_ENTRY(pComboEntry));
+
+	pNameFeedback = gtk_combo_box_get_active_text (GTK_COMBO_BOX (OID ("comboFeedback")));
+	g_assert (pNameFeedback != NULL);
 
 	sprintf (buffer, _("Do you wish to delete this feedback (%s)?"), pNameFeedback);
 
@@ -677,6 +580,7 @@ void gok_page_feedbacks_button_clicked_delete ()
 		pFeedbackDisplayed = pFeedback;
 		pFeedback = pFeedback->pFeedbackNext;
 	}
+	g_free (pNameFeedback);
 
 	m_pFeedbackCurrent = pFeedbackDisplayed;
 	
@@ -689,22 +593,20 @@ void gok_page_feedbacks_button_clicked_delete ()
 }
 
 /**
-* gok_page_feedbacks_check_keyflashing_clicked
-*
-* The checkbox has been clicked. Update the current feedback with the change.
-**/
-void gok_page_feedbacks_check_keyflashing_clicked ()
+ * gok_page_feedbacks_check_keyflashing_toggled:
+ * @button: A #GtkToggleButton
+ *
+ * The checkbox has been clicked. Update the current feedback with the change.
+ **/
+void
+gok_page_feedbacks_check_keyflashing_toggled (GtkToggleButton *button)
 {
-	GtkWidget* pCheckbox;
-	
-	if (m_pFeedbackCurrent == NULL)
+	if (m_pFeedbackCurrent)
 	{
-		return;
+		m_pFeedbackCurrent->bFlashOn = gtk_toggle_button_get_active (button);
+		gtk_widget_set_sensitive (WID ("boxKeyFlashingDetails"),
+					  m_pFeedbackCurrent->bFlashOn);
 	}
-
-	pCheckbox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkKeyFlashing");
-	g_assert (pCheckbox != NULL);
-	m_pFeedbackCurrent->bFlashOn = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(pCheckbox));
 }
 
 /**
@@ -712,63 +614,58 @@ void gok_page_feedbacks_check_keyflashing_clicked ()
 *
 * The spin control has changed. Update the current feedback with the change.
 **/
-void gok_page_feedbacks_spin_keyflashing_changed ()
+void
+gok_page_feedbacks_spin_keyflashing_changed (void)
 {
-	GtkWidget* pSpinControl;
-	
-	if (m_pFeedbackCurrent == NULL)
+	if (m_pFeedbackCurrent)
 	{
-		return;
+		m_pFeedbackCurrent->NumberFlashes =
+			gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (WID ("spinKeyFlashing")));
 	}
-
-	pSpinControl = glade_xml_get_widget (gok_settingsdialog_get_xml(), "spinKeyFlashing");
-	g_assert (pSpinControl != NULL);
-	m_pFeedbackCurrent->NumberFlashes = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(pSpinControl));
 }
 
 /**
-* gok_page_feedbacks_check_sound_clicked
-*
-* The checkbox has been clicked. Update the current feedback with the change.
-**/
-void gok_page_feedbacks_check_sound_clicked ()
+ * gok_page_feedbacks_check_sound_toggled:
+ * @button: A #GtkToggleButton
+ *
+ * The checkbox has been clicked. Update the current feedback with the change.
+ **/
+void
+gok_page_feedbacks_check_sound_toggled (GtkToggleButton *button)
 {
-	GtkWidget* pCheckbox;
-	
-	if (m_pFeedbackCurrent == NULL)
+	if (m_pFeedbackCurrent)
 	{
-		return;
+		m_pFeedbackCurrent->bSoundOn = gtk_toggle_button_get_active (button);
+		gtk_widget_set_sensitive (WID ("boxSoundFile"),
+					  m_pFeedbackCurrent->bSoundOn);
 	}
-
-	pCheckbox = glade_xml_get_widget (gok_settingsdialog_get_xml(), "checkSoundOn");
-	g_assert (pCheckbox != NULL);
-	m_pFeedbackCurrent->bSoundOn = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(pCheckbox));
 }
 
 /**
-* gok_page_feedbacks_check_speech_toggled
-*
-* The checkbox has been toggled. Update the current feedback with the change.
-**/
-void gok_page_feedbacks_check_speech_toggled (GtkToggleButton *button)
+ * gok_page_feedbacks_check_speech_toggled:
+ * @button: A #GtkToggleButton
+ *
+ * The checkbox has been toggled. Update the current feedback with the change.
+ **/
+void
+gok_page_feedbacks_check_speech_toggled (GtkToggleButton *button)
 {
-	if (m_pFeedbackCurrent == NULL)
+	if (m_pFeedbackCurrent)
 	{
-		return;
+		m_pFeedbackCurrent->bSpeechOn = gtk_toggle_button_get_active (button);
 	}
-
-	m_pFeedbackCurrent->bSpeechOn = gtk_toggle_button_get_active (button);
 }
 
 /**
-* gok_page_feedbacks_entry_soundname_changed
-*
-* The sound file name has changed. Update the current feedback with the change.
-**/
-void gok_page_feedbacks_entry_soundname_changed ()
+ * gok_page_feedbacks_soundname_changed:
+ * @combo: A #GtkComboBox
+ *
+ * The sound file has changed. Update the current feedback with the change.
+ **/
+void gok_page_feedbacks_soundname_changed (GtkComboBox *combo)
 {
-	GtkWidget* pEntry;
-	
+	gchar *soundfile;
+
 	if (m_bIgnoreSoundNameChange == TRUE)
 	{
 		return;
@@ -779,28 +676,26 @@ void gok_page_feedbacks_entry_soundname_changed ()
 		return;
 	}
 
-	pEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entrySoundName");
-	g_assert (pEntry != NULL);
-
+	soundfile = gtk_combo_box_get_active_text (combo);
 	/* is there a sound file selected? */
-	if (strlen (gtk_entry_get_text (GTK_ENTRY(pEntry))) > 0)
+	if (soundfile && strlen (soundfile) > 0)
 	{
 		/* yes, there is a sound file selected */
 		/* does the feedback already have a sound file name? */
 		if (m_pFeedbackCurrent->pNameSound != NULL)
 		{
 			/* yes, is the feedback name the same as the name in the entry? */
-			if (strcmp (m_pFeedbackCurrent->pNameSound, gtk_entry_get_text (GTK_ENTRY(pEntry))) != 0)
+			if (strcmp (m_pFeedbackCurrent->pNameSound, soundfile) != 0)
 			{
 				/* no, names are different */
 				/* free the existing name and store the new name */
 				g_free (m_pFeedbackCurrent->pNameSound);	
-                                m_pFeedbackCurrent->pNameSound = g_strdup (gtk_entry_get_text (GTK_ENTRY(pEntry)));
+				m_pFeedbackCurrent->pNameSound = g_strdup (soundfile);
 			}
 		}
 		else /* feedback does not have a sound file name */
 		{
-                    m_pFeedbackCurrent->pNameSound = g_strdup (gtk_entry_get_text (GTK_ENTRY(pEntry)));
+			m_pFeedbackCurrent->pNameSound = g_strdup (soundfile);
 		}
 	}
 	else /* no sound file selected */
@@ -811,6 +706,7 @@ void gok_page_feedbacks_entry_soundname_changed ()
 			m_pFeedbackCurrent->pNameSound = NULL;
 		}
 	}
+	g_free (soundfile);
 }
 
 /**
@@ -818,35 +714,30 @@ void gok_page_feedbacks_entry_soundname_changed ()
 *
 * Adds all the sounds from the feedbacks to the 'sounds' combo box list.
 **/
-void gok_feedbacks_update_sound_combo()
+void gok_feedbacks_update_sound_combo (void)
 {
-	GtkWidget* pCombo;
-	GList* items = NULL;
+	GtkComboBox* pCombo;
 	GokFeedback* pFeedback;
+	GtkTreeIter iter;
 
-	pCombo = glade_xml_get_widget (gok_settingsdialog_get_xml(), "comboSoundName");
-	g_assert (pCombo != NULL);
+	m_bIgnoreSoundNameChange = TRUE;
+
+	pCombo = GTK_COMBO_BOX (OID ("comboSoundName"));
+	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (pCombo)));
 
 	pFeedback = gok_feedback_get_first_feedback();
 	while (pFeedback != NULL)
 	{
-		if (pFeedback->pNameSound != NULL)
+		/* don't allow duplicate sound file entries */
+		if (pFeedback->pNameSound != NULL &&
+		    !gok_settingsdialog_combobox_search (pCombo, pFeedback->pNameSound, &iter))
 		{
-			items = g_list_append (items, pFeedback->pNameSound);
+			gtk_combo_box_prepend_text (pCombo, pFeedback->pNameSound);
 		}
 		pFeedback = pFeedback->pFeedbackNext;
 	}
 
-	if (items != NULL)
-	{
-		/* sort the names */
-		items = g_list_sort (items, gok_settingsdialog_sort);
-
-		m_bIgnoreSoundNameChange = TRUE;
-		gtk_combo_set_popdown_strings (GTK_COMBO (pCombo), items);
-		g_list_free (items);
-		m_bIgnoreSoundNameChange = FALSE;
-	}
+	m_bIgnoreSoundNameChange = FALSE;
 }
 
 /**
@@ -859,7 +750,6 @@ void gok_page_feedbacks_get_sound_file ()
 	GtkWidget* pDialogFilename;
 	gint response;
 	gchar* filename;
-	GtkWidget* pEntry;
 
 	/* make sure the current feedback is not NULL */
 	if (m_pFeedbackCurrent == NULL)
@@ -901,11 +791,9 @@ void gok_page_feedbacks_get_sound_file ()
 	/* update the combo box list */
 	gok_feedbacks_update_sound_combo();
 	
-	/* display it in the entry of the combo box */
-	pEntry = glade_xml_get_widget (gok_settingsdialog_get_xml(), "entrySoundName");
-	g_assert (pEntry != NULL);
+	/* display it in the combo box */
 	m_bIgnoreSoundNameChange = TRUE;
-	gtk_entry_set_text (GTK_ENTRY(pEntry), filename);
+	gok_settingsdialog_combobox_set_active (GTK_COMBO_BOX (OID ("comboSoundName")), filename);
 	m_bIgnoreSoundNameChange = FALSE;
 
 	/* destroy the file selector dialog */
