@@ -33,7 +33,6 @@
 #endif
 
 #include <locale.h>
-#include <libgnome/gnome-macros.h>
 
 #include "gok-word-complete.h"
 #include "gok-keyslotter.h"
@@ -72,11 +71,10 @@ struct _GokWordCompletePrivate
 
 static GokWordComplete *default_wordcomplete_engine = NULL;
 
-GNOME_CLASS_BOILERPLATE (GokWordComplete, gok_wordcomplete, 
-			 GObject, G_TYPE_OBJECT)
+G_DEFINE_TYPE (GokWordComplete, gok_wordcomplete, G_TYPE_OBJECT)
 
 static void
-gok_wordcomplete_instance_init (GokWordComplete *complete)
+gok_wordcomplete_init (GokWordComplete *complete)
 {
 	complete->priv = g_new0 (GokWordCompletePrivate, 1);
 	complete->priv->word_part = NULL;
@@ -118,7 +116,7 @@ gok_wordcomplete_finalize (GObject *obj)
 
 	if (complete && complete->priv)
 		g_free (complete->priv);
-	G_OBJECT_CLASS (GOK_WORDCOMPLETE_GET_CLASS (obj))->finalize (obj);
+	G_OBJECT_CLASS (gok_wordcomplete_parent_class)->finalize (obj);
 }
 
 /**
