@@ -63,7 +63,6 @@
 #include "gok-sound.h"
 #include "gok-log.h"
 #include "gok-gconf-keys.h"
-#include "gok-predictor.h"
 #include "gok-editor.h"
 #include "gok-spy.h"
 #include "gok-feedback.h"
@@ -143,9 +142,6 @@ static gint m_GeometryHeight = -1;
 static gint m_GeometryX = -1;
 static gint m_GeometryY = -1;
 
-/* pointer to the gok command predictor */
-static Gok_Predictor m_pCommandPredictor = NULL;
-
 /* command line aguments storage structure */
 typedef struct _GokArgs {
 	char* accessmethodname;
@@ -181,7 +177,6 @@ static struct {
 static void gok_main_read_rc (void);
 static void gok_main_initialize_access_methods (GokArgs *args);
 static void gok_main_initialize_wordcomplete (void);
-static void gok_main_initialize_commandprediction (void);
 static gboolean gok_main_display_scan_main(void);
 static void gok_main_object_state_listener (Accessible* pAccessible);
 static gboolean gok_main_has_xkb_extension ();
@@ -963,7 +958,6 @@ gok_main_open(gint argc, gchar *argv[])
 	gok_log ("login mode = %s\n", gok_args.is_login ? "true" : "false");
 	if (!gok_args.is_login) {
 		gok_main_initialize_wordcomplete ();
-		gok_main_initialize_commandprediction ();
 	}
 
 	/* create the settings dialog */
@@ -1106,18 +1100,6 @@ gok_main_set_cursor (GdkCursor *cursor)
 	gdk_window_set_cursor (gok_main_get_main_window ()->window, cursor);
 }
 
-/**
-* gok_main_get_command_predictor
-* 
-* Accessor function.
-*
-* returns: A pointer to command prediction engine
-*/
-Gok_Predictor gok_main_get_command_predictor ()
-{
-	return m_pCommandPredictor;
-}
-
 /**
 * gok_main_get_foreground_window_accessible
 * 
@@ -1882,8 +1864,6 @@ gboolean gok_main_ds (GokKeyboard* pKeyboard)
 	/* enable/disable the menu and toolbar keys */
 	gok_keyboard_validate_dynamic_keys (gok_main_get_foreground_window_accessible());
 
-	/* if there are command prediction keys - fill them in */
-	gok_predictor_predict(m_pCommandPredictor);
 
 	/* initialize the current access method */
 	gok_scanner_reset_access_method ();
@@ -2395,49 +2375,6 @@ gok_main_initialize_wordcomplete ()
     g_free (directory_name);
 }
 
-/**
-* gok_main_initialize_commandpredictione:
-*
-* Retreives the name of the directory containing dictionary.txt from
-* GConf and calls gok_wordcomplete_open passing that directory.
-*/
-static void
-gok_main_initialize_commandprediction ()
-{
-	gok_log_enter();
-    /* intialize command predictor */
-    m_pCommandPredictor = gok_predictor_open();
-   /*
-    GConfClient *gconf_client = NULL;
-    GError *gconf_err = NULL;
-    gchar *directory_name = NULL;
-
-    gconf_client = gconf_client_get_default ();
-    
-    directory_name = gconf_client_get_string (gconf_client,
-					      GOK_GCONF_DICTIONARY_DIRECTORY,
-					      &gconf_err);
-    if (directory_name == NULL)
-    {
-	gok_log_x ("Got NULL dictionary directory key from GConf");
-    }
-    else if (gconf_err != NULL)
-    {
-	gok_log_x ("Error getting dictionary directory key from GConf");
-	g_error_free (gconf_err);
-    }
-    else
-    {
-	if ( !(gok_wordcomplete_open (directory_name)) ) {
-	    gok_log_x ("Error initializing word completion");
-	}
-	
-	g_free (directory_name);
-    }
-    */
-	gok_log_leave();
-}
-
 /**
 * gok_main_resize_window
 * @pWindow: Pointer to the main window.
@@ -2804,7 +2741,6 @@ gok_main_close()
 	gok_feedback_close();
 	gok_control_button_callback_close();
 	gok_wordcomplete_close(gok_wordcomplete_get_default ());
-	gok_predictor_close(m_pCommandPredictor);
 	
 	_exit(0);
 }
